if test "$POST_RECOVERY_SCRIPT" ; then
	Log "Running POST_RECOVERY_SCRIPT '${POST_RECOVERY_SCRIPT[@]}'"
	eval "${POST_RECOVERY_SCRIPT[@]}"
fi
